@@ -26,11 +26,11 @@
 #include <glib/gmacros.h>
 #include <libgda/gda-connection.h>
 #include <libgda/gda-server-provider.h>
-#include <glib/gi18n-lib.h>
+#include <libgda/gda-intl.h>
 #include <libgda/gda-value.h>
+#include "gda-mdb-provider.h"
 #include <mdbtools.h>
 #include <mdbsql.h>
-#include "gda-mdb-provider.h"
 
 #define GDA_MYSQL_PROVIDER_ID          "GDA MDB provider"
 
