@@ -39,29 +39,29 @@ G_BEGIN_DECLS
 
 typedef gboolean (*sybase_conv_Func) (GdaSybaseConnectionData *scnc,
                                       GdaSybaseField          *field,
-                                      GValue                *value);
+                                      GdaValue                *value);
 
 typedef struct _sybase_Types {
   gchar            *name;
   CS_INT           sql_type;
-  GType     g_type;
+  GdaValueType     gda_type;
 //  sybase_conv_Func conv_sql2gda;
 } sybase_Types;
 
 #define GDA_SYBASE_TYPE_CNT 23
 extern const sybase_Types gda_sybase_type_list[GDA_SYBASE_TYPE_CNT];
 
-const GType gda_sybase_get_value_type (const CS_INT sql_type);
-const CS_INT gda_sybase_get_sql_type (const GType g_type);
+const GdaValueType gda_sybase_get_value_type (const CS_INT sql_type);
+const CS_INT gda_sybase_get_sql_type (const GdaValueType gda_type);
 
-void gda_sybase_set_value_by_datetime(GValue *value, CS_DATETIME *dt);
-void gda_sybase_set_value_by_datetime4(GValue *value, CS_DATETIME4 *dt);
+void gda_sybase_set_value_by_datetime(GdaValue *value, CS_DATETIME *dt);
+void gda_sybase_set_value_by_datetime4(GdaValue *value, CS_DATETIME4 *dt);
 
 const gboolean gda_sybase_set_gda_value (GdaSybaseConnectionData *scnc,
-                                         GValue *value, 
+                                         GdaValue *value, 
                                          GdaSybaseField *field);
 const gboolean gda_sybase_set_value_general (GdaSybaseConnectionData *scnc,
-                                             GValue                *value,
+                                             GdaValue                *value,
                                              GdaSybaseField          *field);
 
 
